==> sqldelight-oracle-dialect-0.0.12-sources.jar: app/softwork/sqldelight/oracledialect/grammar/psi/OracleVisitor.java <==
// This is a generated file. Not intended for manual editing.
package app.softwork.sqldelight.oracledialect.grammar.psi;

import org.jetbrains.annotations.*;
import com.intellij.psi.PsiElementVisitor;
import com.alecstrong.sql.psi.core.psi.SqlCompositeElement;
import com.alecstrong.sql.psi.core.psi.SqlTypeName;
import com.alecstrong.sql.psi.core.psi.SqlExtensionStmt;
import com.alecstrong.sql.psi.core.psi.SqlLiteralValue;
import com.alecstrong.sql.psi.core.psi.SqlGeneratedClause;
import com.alecstrong.sql.psi.core.psi.SqlBindParameter;
import com.alecstrong.sql.psi.core.psi.SqlDefaultConstraint;

public class OracleVisitor extends PsiElementVisitor {

  public void visitAlterTablespace(@NotNull OracleAlterTablespace o) {
    visitSqlCompositeElement(o);
  }

  public void visitApproximateNumericDataType(@NotNull OracleApproximateNumericDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitBigIntDataType(@NotNull OracleBigIntDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitBinaryLargeObjectStringDataType(@NotNull OracleBinaryLargeObjectStringDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitBinaryStringDataType(@NotNull OracleBinaryStringDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitBindParameter(@NotNull OracleBindParameter o) {
    visitSqlBindParameter(o);
  }

  public void visitBitStringDataType(@NotNull OracleBitStringDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitBooleanDataType(@NotNull OracleBooleanDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitCharLengthUnits(@NotNull OracleCharLengthUnits o) {
    visitSqlCompositeElement(o);
  }

  public void visitCharacterLargeObjectDataType(@NotNull OracleCharacterLargeObjectDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitCharacterLargeObjectLength(@NotNull OracleCharacterLargeObjectLength o) {
    visitSqlCompositeElement(o);
  }

  public void visitCharacterStringDataType(@NotNull OracleCharacterStringDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitCreateUser(@NotNull OracleCreateUser o) {
    visitSqlCompositeElement(o);
  }

  public void visitDateDataType(@NotNull OracleDateDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitDefaultConstraint(@NotNull OracleDefaultConstraint o) {
    visitSqlDefaultConstraint(o);
  }

  public void visitEndField(@NotNull OracleEndField o) {
    visitSqlCompositeElement(o);
  }

  public void visitExtensionStmt(@NotNull OracleExtensionStmt o) {
    visitSqlExtensionStmt(o);
  }

  public void visitFixedPointDataType(@NotNull OracleFixedPointDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitGeneratedClause(@NotNull OracleGeneratedClause o) {
    visitSqlGeneratedClause(o);
  }

  public void visitGrantSession(@NotNull OracleGrantSession o) {
    visitSqlCompositeElement(o);
  }

  public void visitGrantTable(@NotNull OracleGrantTable o) {
    visitSqlCompositeElement(o);
  }

  public void visitIntDataType(@NotNull OracleIntDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitIntervalDataType(@NotNull OracleIntervalDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitIntervalQualifier(@NotNull OracleIntervalQualifier o) {
    visitSqlCompositeElement(o);
  }

  public void visitLiteralValue(@NotNull OracleLiteralValue o) {
    visitSqlLiteralValue(o);
  }

  public void visitMultiplier(@NotNull OracleMultiplier o) {
    visitSqlCompositeElement(o);
  }

  public void visitNonSecondPrimaryDatetimeField(@NotNull OracleNonSecondPrimaryDatetimeField o) {
    visitSqlCompositeElement(o);
  }

  public void visitOverrides(@NotNull OracleOverrides o) {
    visitSqlCompositeElement(o);
  }

  public void visitOverridesReal(@NotNull OracleOverridesReal o) {
    visitSqlCompositeElement(o);
  }

  public void visitPrecision(@NotNull OraclePrecision o) {
    visitSqlCompositeElement(o);
  }

  public void visitScale(@NotNull OracleScale o) {
    visitSqlCompositeElement(o);
  }

  public void visitSingleDatetimeField(@NotNull OracleSingleDatetimeField o) {
    visitSqlCompositeElement(o);
  }

  public void visitSmallIntDataType(@NotNull OracleSmallIntDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitStartField(@NotNull OracleStartField o) {
    visitSqlCompositeElement(o);
  }

  public void visitTypeName(@NotNull OracleTypeName o) {
    visitSqlTypeName(o);
  }

  public void visitSqlBindParameter(@NotNull SqlBindParameter o) {
    visitElement(o);
  }

  public void visitSqlDefaultConstraint(@NotNull SqlDefaultConstraint o) {
    visitElement(o);
  }

  public void visitSqlExtensionStmt(@NotNull SqlExtensionStmt o) {
    visitElement(o);
  }

  public void visitSqlGeneratedClause(@NotNull SqlGeneratedClause o) {
    visitElement(o);
  }

  public void visitSqlLiteralValue(@NotNull SqlLiteralValue o) {
    visitElement(o);
  }

  public void visitSqlTypeName(@NotNull SqlTypeName o) {
    visitElement(o);
  }

  public void visitSqlCompositeElement(@NotNull SqlCompositeElement o) {
    visitElement(o);
  }

}

==> sqldelight-oracle-dialect-0.0.14-sources.jar: app/softwork/sqldelight/oracledialect/grammar/psi/OracleVisitor.java <==
// This is a generated file. Not intended for manual editing.
package app.softwork.sqldelight.oracledialect.grammar.psi;

import org.jetbrains.annotations.*;
import com.intellij.psi.PsiElementVisitor;
import com.alecstrong.sql.psi.core.psi.SqlCompositeElement;
import com.alecstrong.sql.psi.core.psi.SqlTypeName;
import com.alecstrong.sql.psi.core.psi.SqlExtensionStmt;
import com.alecstrong.sql.psi.core.psi.SqlLiteralValue;
import com.alecstrong.sql.psi.core.psi.SqlGeneratedClause;
import com.alecstrong.sql.psi.core.psi.SqlBindParameter;
import com.alecstrong.sql.psi.core.psi.SqlDefaultConstraint;
import com.alecstrong.sql.psi.core.psi.SqlInsertStmt;

public class OracleVisitor extends PsiElementVisitor {

  public void visitAlterTablespace(@NotNull OracleAlterTablespace o) {
    visitSqlCompositeElement(o);
  }

  public void visitAlterTablespaceReal(@NotNull OracleAlterTablespaceReal o) {
    visitSqlCompositeElement(o);
  }

  public void visitApproximateNumericDataType(@NotNull OracleApproximateNumericDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitBigIntDataType(@NotNull OracleBigIntDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitBinaryLargeObjectStringDataType(@NotNull OracleBinaryLargeObjectStringDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitBinaryStringDataType(@NotNull OracleBinaryStringDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitBindParameter(@NotNull OracleBindParameter o) {
    visitSqlBindParameter(o);
  }

  public void visitBitStringDataType(@NotNull OracleBitStringDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitBooleanDataType(@NotNull OracleBooleanDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitCharLengthUnits(@NotNull OracleCharLengthUnits o) {
    visitSqlCompositeElement(o);
  }

  public void visitCharacterLargeObjectDataType(@NotNull OracleCharacterLargeObjectDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitCharacterLargeObjectLength(@NotNull OracleCharacterLargeObjectLength o) {
    visitSqlCompositeElement(o);
  }

  public void visitCharacterStringDataType(@NotNull OracleCharacterStringDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitCreateUser(@NotNull OracleCreateUser o) {
    visitSqlCompositeElement(o);
  }

  public void visitDateDataType(@NotNull OracleDateDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitDefaultConstraint(@NotNull OracleDefaultConstraint o) {
    visitSqlDefaultConstraint(o);
  }

  public void visitEndField(@NotNull OracleEndField o) {
    visitSqlCompositeElement(o);
  }

  public void visitExtensionStmt(@NotNull OracleExtensionStmt o) {
    visitSqlExtensionStmt(o);
  }

  public void visitFixedPointDataType(@NotNull OracleFixedPointDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitGeneratedClause(@NotNull OracleGeneratedClause o) {
    visitSqlGeneratedClause(o);
  }

  public void visitGrantSession(@NotNull OracleGrantSession o) {
    visitSqlCompositeElement(o);
  }

  public void visitGrantTable(@NotNull OracleGrantTable o) {
    visitSqlCompositeElement(o);
  }

  public void visitIntDataType(@NotNull OracleIntDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitIntervalDataType(@NotNull OracleIntervalDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitIntervalQualifier(@NotNull OracleIntervalQualifier o) {
    visitSqlCompositeElement(o);
  }

  public void visitLiteralValue(@NotNull OracleLiteralValue o) {
    visitSqlLiteralValue(o);
  }

  public void visitMerge(@NotNull OracleMerge o) {
    visitSqlCompositeElement(o);
  }

  public void visitMergeInsertClause(@NotNull OracleMergeInsertClause o) {
    visitSqlInsertStmt(o);
  }

  public void visitMergeOn(@NotNull OracleMergeOn o) {
    visitSqlCompositeElement(o);
  }

  public void visitMergeUpdateClause(@NotNull OracleMergeUpdateClause o) {
    visitSqlCompositeElement(o);
  }

  public void visitMergeUpdateColumnClause(@NotNull OracleMergeUpdateColumnClause o) {
    visitSqlCompositeElement(o);
  }

  public void visitMergeUpdateColumnClauseSingle(@NotNull OracleMergeUpdateColumnClauseSingle o) {
    visitSqlCompositeElement(o);
  }

  public void visitMultiplier(@NotNull OracleMultiplier o) {
    visitSqlCompositeElement(o);
  }

  public void visitNonSecondPrimaryDatetimeField(@NotNull OracleNonSecondPrimaryDatetimeField o) {
    visitSqlCompositeElement(o);
  }

  public void visitOverrides(@NotNull OracleOverrides o) {
    visitSqlCompositeElement(o);
  }

  public void visitOverridesReal(@NotNull OracleOverridesReal o) {
    visitSqlCompositeElement(o);
  }

  public void visitPrecision(@NotNull OraclePrecision o) {
    visitSqlCompositeElement(o);
  }

  public void visitScale(@NotNull OracleScale o) {
    visitSqlCompositeElement(o);
  }

  public void visitSingleDatetimeField(@NotNull OracleSingleDatetimeField o) {
    visitSqlCompositeElement(o);
  }

  public void visitSmallIntDataType(@NotNull OracleSmallIntDataType o) {
    visitSqlCompositeElement(o);
  }

  public void visitStartField(@NotNull OracleStartField o) {
    visitSqlCompositeElement(o);
  }

  public void visitTypeName(@NotNull OracleTypeName o) {
    visitSqlTypeName(o);
  }

  public void visitSqlBindParameter(@NotNull SqlBindParameter o) {
    visitElement(o);
  }

  public void visitSqlDefaultConstraint(@NotNull SqlDefaultConstraint o) {
    visitElement(o);
  }

  public void visitSqlExtensionStmt(@NotNull SqlExtensionStmt o) {
    visitElement(o);
  }

  public void visitSqlGeneratedClause(@NotNull SqlGeneratedClause o) {
    visitElement(o);
  }

  public void visitSqlInsertStmt(@NotNull SqlInsertStmt o) {
    visitElement(o);
  }

  public void visitSqlLiteralValue(@NotNull SqlLiteralValue o) {
    visitElement(o);
  }

  public void visitSqlTypeName(@NotNull SqlTypeName o) {
    visitElement(o);
  }

  public void visitSqlCompositeElement(@NotNull SqlCompositeElement o) {
    visitElement(o);
  }

}
